import React, { PureComponent } from "react"
import { VList } from '@/common'
import './my-courses.scss'
import { isToday, format } from "date-fns"
import { connect } from "react-redux"
import { getMyCourses } from "./actions"

function getStudyTime(seconds) {
    return {
        hour: Math.floor(seconds / (60 * 60)),
        min: Math.floor(seconds / 60) % 60,
        sec: seconds % 60
    }
}


function AddCourse(props) {
    return (
        <div className='add-course'>
            <button className='add' onClick={props.addCourseClick}>添加课程+</button>
        </div>
    )
}

function Record({record: {seconds, lesson_name}}) {
    let re = /第[\s\S]+?课/,
        result = ''

    if (lesson_name) {
        let matchResult = re.exec(lesson_name)
        result += (matchResult && matchResult[0]) ? matchResult[0] : ''
    }

    if (seconds) {
        let studyTime = getStudyTime(seconds)
        let hour = studyTime.hour ? String(studyTime.hour).padStart(2, '0') + ':' : '',
            min = studyTime.min ? String(studyTime.min).padStart(2, '0') + ':' : '',
            sec = studyTime.sec ? String(studyTime.sec).padStart(2, '0') : ''

        result += hour + min + sec
    }

    return (
        <span className={'record'}>
            {
                result.length ? `学习到${result}` : null
            }
        </span>
    )
}

class MyCourses extends PureComponent {

    state = {
        addVisible: false
    }

    handleClick = () => {
        console.log(1);
    }
    addCourseClick = () => {
        console.log(2);
    }

    componentDidMount() {
        this.props.getMyCourses({page: 1, num: 10});
    }

    render() {
        let {data} = this.props.courseData
        if (data && data.length !== 0) {
            return (
                <>
                    <ul>
                        {
                            data.map((item, index) => {

                                let date = new Date(item.ago * 1000)
                                let time = isToday(date) ? format(date, 'HH时mm分') : format(date, 'MM月DD日')

                                const Info = (
                                    <div className="info">
                                        <p className='title'>{item.course_title}</p>
                                        <p className='contact'>QQ群：{item.course_qq || 449141326}</p>
                                        <p className='des'>
                                            <span className='time'>{time}</span>
                                            <Record record={item}/>
                                        </p>
                                    </div>
                                )
                                return (
                                    <VList img={item.image_name}
                                           handleClick={this.handleClick}
                                           {...item}
                                           key={index}
                                           info={Info}/>
                                )
                            })
                        }
                    </ul>
                    {
                        this.state.addVisible ?
                            <AddCourse addCourseClick={this.addCourseClick}/>
                            : null
                    }
                </>
            )
        } else {
            return (
                <div className="empty">
                    <p><i className='iconfont iconfish'/></p>
                    <p className='empty-prompt'>还是咸鱼一条，快去翻身~</p>
                    <p>
                        <button>去选课</button>
                    </p>
                </div>
            )
        }

    }
}

const mapStateToProps = state => ({
    courseData: state.myCourses.courseData
})

const mapDispatchToProps = {getMyCourses}

export default connect(mapStateToProps, mapDispatchToProps)(MyCourses)